aboutsummaryrefslogtreecommitdiffstats
path: root/docs/research/054-direct-document-path.md
diff options
context:
space:
mode:
authoreunhhu <[email protected]>2026-09-30 07:18:03 +0100
committereunhhu <[email protected]>2026-09-30 07:18:03 +0100
commit155b73513017c79dcf235b53f0b4942e80dc2e29 (patch)
treeca0c9818dc1963243f73429a9106a12f17dd0da4 /docs/research/054-direct-document-path.md
parent31a5ff8ba64d505c3c01ee0c6b4d55bd06c167d5 (diff)
downloadpure-155b73513017c79dcf235b53f0b4942e80dc2e29.tar.gz
pure-155b73513017c79dcf235b53f0b4942e80dc2e29.zip
Checkpoint TPC-C's SQLite each 40 MB of WAL, as tuning on both devices chose
Its default, each 1,000 pages, is 1 MB of WAL with the 1 KiB pages the SD card favours: grouped commits there went from 203 to 694 a second, and in RAM a thread's p99 from 1.2 to 0.2 ms (docs/research/106).
Diffstat (limited to 'docs/research/054-direct-document-path.md')
0 files changed, 0 insertions, 0 deletions